using Gtk;
using Gdk;
public class Preferences : Gtk.Window
{
	//define some signals
	signal void emit_preferences(Color charge,Color drain, Color border,Color background,string wp,string wc,string cp,string cc);
	
	signal void destroyed();
	
	private ColorButton borderButton;
	private ColorButton chargingButton;
	private ColorButton drainingButton;
	private ColorButton backgroundButton;
	private SpinButton warningPercent;
	private SpinButton criticalPercent;
	private Entry warningCommand;
	private Entry criticalCommand;
	
	public Preferences()
	{
		type = Gtk.WindowType.TOPLEVEL;
		//set_decorated(false);
		set_modal(true);
		set_resizable(false);
		set_title("Preferences");
		set_deletable(false);
		
		VBox topVbox = new VBox(false,5);
		topVbox.set_border_width(3);
		//add the topVbox to the window
		add(topVbox);
		Table table = new Table(4,2,false);
		table.set_border_width(3);
		table.set_col_spacings(3);
		table.set_row_spacings(3);
		Frame colorsFrame = new Frame("Colors");
		colorsFrame.add(table);
		
		borderButton = new ColorButton();
		chargingButton = new ColorButton();
		drainingButton = new ColorButton();
		backgroundButton = new ColorButton();
		Alignment align;

		Label chargingLabel = new Label("Charging:");
		chargingLabel.set_alignment(0,(float)0.5);
		//add the label to the table
		table.attach(chargingLabel,0,1,0,1,AttachOptions.FILL,AttachOptions.FILL,0,0);
		align = new Alignment(0,0,0,0);
		align.add(chargingButton);
		table.attach(align,1,2,0,1,AttachOptions.FILL,AttachOptions.FILL,0,0);

		Label drainingLabel = new Label("Draining:");
		drainingLabel.set_alignment(0,(float)0.5);
		//add the label to the table
		table.attach(drainingLabel,0,1,1,2,AttachOptions.FILL,AttachOptions.FILL,0,0);
		align = new Alignment(0,0,0,0);
		align.add(drainingButton);
		table.attach(align,1,2,1,2,AttachOptions.FILL,AttachOptions.FILL,0,0);
		
		Label borderLabel = new Label("Border:");
		borderLabel.set_alignment(0,(float)0.5);
		//add the label to the table
		table.attach(borderLabel,0,1,2,3,AttachOptions.FILL,AttachOptions.FILL,0,0);
		align = new Alignment(0,0,0,0);
		align.add(borderButton);
		table.attach(align,1,2,2,3,AttachOptions.FILL,AttachOptions.FILL,0,0);
		
		Label backgroundLabel = new Label("Background:");
		backgroundLabel.set_alignment(0,(float)0.5);
		//add the label to the table
		table.attach(backgroundLabel,0,1,3,4,AttachOptions.FILL,AttachOptions.FILL,0,0);
		align = new Alignment(0,0,0,0);
		align.add(backgroundButton);
		table.attach(align,1,2,3,4,AttachOptions.FILL,AttachOptions.FILL,0,0);

		//add the colors frame to the topVbox
		topVbox.add(colorsFrame);
		/* make stuff for warning */
		Frame warningFrame = new Frame("Warning");
		//add the frame to the window
		topVbox.add(warningFrame);
		table = new Table(2,2,false);
		table.set_border_width(3);
		table.set_col_spacings(3);
		table.set_row_spacings(3);
		warningFrame.add(table);
		Label percentLabel = new Label("Percent:");
		percentLabel.set_alignment(0,(float)0.5);
		table.attach(percentLabel,0,1,0,1,AttachOptions.FILL,AttachOptions.FILL,0,0);
		//create the warningPercent spinbutton
		warningPercent= new SpinButton.with_range(0,100,1);
		align = new Alignment(0,0,0,0);
		align.add(warningPercent);
		table.attach(align,1,2,0,1,AttachOptions.FILL,AttachOptions.FILL,0,0);
		Label commandLabel = new Label("Command:");
		commandLabel.set_alignment(0,0);
		table.attach(commandLabel,0,1,1,2,AttachOptions.EXPAND,AttachOptions.EXPAND,0,0);
		//create and add the warning text box
		warningCommand = new Entry();
		table.attach(warningCommand,1,2,1,2,AttachOptions.FILL,AttachOptions.FILL,0,0);
		/* make stuff for critical */
		Frame criticalFrame = new Frame("Critical");
		//add the frame to the window
		topVbox.add(criticalFrame);
		table = new Table(2,2,false);
		table.set_border_width(3);
		table.set_col_spacings(3);
		table.set_row_spacings(3);
		criticalFrame.add(table);
		percentLabel = new Label("Percent:");
		percentLabel.set_alignment(0,(float)0.5);
		table.attach(percentLabel,0,1,0,1,AttachOptions.FILL,AttachOptions.FILL,0,0);
		//create the criticalPercent spinbutton
		criticalPercent= new SpinButton.with_range(0,100,1);
		align = new Alignment(0,0,0,0);
		align.add(criticalPercent);
		table.attach(align,1,2,0,1,AttachOptions.FILL,AttachOptions.FILL,0,0);
		commandLabel = new Label("Command:");
		commandLabel.set_alignment(0,0);
		table.attach(commandLabel,0,1,1,2,AttachOptions.EXPAND,AttachOptions.EXPAND,0,0);
		//create and add the critical text box
		criticalCommand = new Entry();
		table.attach(criticalCommand,1,2,1,2,AttachOptions.FILL,AttachOptions.FILL,0,0);
		/* add some OK/Cancel buttons */
		HButtonBox bbox = new HButtonBox();
		bbox.set_layout(ButtonBoxStyle.END);
		//add the bbox to the topVpanel
		topVbox.add(bbox);
		Button OKButton = new Button.from_stock(Gtk.STOCK_OK);
		OKButton.clicked.connect( update_app );
		bbox.add(OKButton);
		Button cancelButton = new Button.from_stock(Gtk.STOCK_CANCEL);
		cancelButton.clicked.connect( do_destroy );
		bbox.add(cancelButton);
		//set the frames border width
		set_border_width(5);
		show_all();
		destroy.connect( destruct );
	}
	public void update_app()
	{
		//harvest the interface bits and send as a signal
		//get the colors
		Color charging,draining,border,background;
		chargingButton.get_color(out charging);
		drainingButton.get_color(out draining);
		borderButton.get_color(out border);
		backgroundButton.get_color(out background);

		//get the percents and commands
		string wp = warningPercent.get_value().to_string();
		string wc = warningCommand.get_text();
		string cp = criticalPercent.get_value().to_string();
		string cc = criticalCommand.get_text();
		//emit the signal
		emit_preferences(charging,draining,border,background,wp,wc,cp,cc);
		//now destroy the interface
		destroy();
	}

	public void do_destroy()
	{
		destroy();
	}
	public void destruct()
	{
		this.destroyed();
	}
	public void set_colors(string charging, string draining, string border, string background)
	{
		Color color;
		//update the button colors
		Gdk.Color.parse(charging,out color);
		chargingButton.set_color(color);
		Gdk.Color.parse(draining,out color);
		drainingButton.set_color(color);
		Gdk.Color.parse(border,out color);
		borderButton.set_color(color);
		Gdk.Color.parse(background,out color);
		backgroundButton.set_color(color);
	}
	public void set_warnings(string wp,string wc,string cp,string cc)
	{
		warningPercent.set_value( wp.to_int() );
		criticalPercent.set_value( cp.to_int() );
		warningCommand.set_text( wc );
		criticalCommand.set_text( cc );
	}
	public void display()
	{
		show_all();
	}
}

public class IconMenu : Gtk.Menu
{
	//what signals do we have?
	signal void show_preferences();
	signal void show_about();
	
	public IconMenu()
	{
		
		ImageMenuItem menuItem = new Gtk.ImageMenuItem.from_stock(Gtk.STOCK_PREFERENCES,null);
		menuItem.activate.connect((source)=>{ show_preferences(); });
		append(menuItem);
		
		menuItem = new Gtk.ImageMenuItem.from_stock(Gtk.STOCK_ABOUT,null);
		menuItem.activate.connect((source)=>{show_about(); });
		append(menuItem);
		//attach(menuItem,0,1,0,1);
		show_all();
	}
}
